@@ -10,10 +10,11 @@ import (
 	log "github.com/sirupsen/logrus"
 	"github.com/sirupsen/logrus/hooks/writer"
 
+	"github.com/crowdsecurity/go-cs-lib/pkg/trace"
+	"github.com/crowdsecurity/go-cs-lib/pkg/version"
+
 	"github.com/crowdsecurity/crowdsec/pkg/csconfig"
-	"github.com/crowdsecurity/crowdsec/pkg/cwversion"
 	"github.com/crowdsecurity/crowdsec/pkg/database"
-	"github.com/crowdsecurity/crowdsec/pkg/types"
 )
 
 func StartRunSvc() error {
@@ -22,7 +23,7 @@ func StartRunSvc() error {
 		err     error
 	)
 
-	defer types.CatchPanic("crowdsec/StartRunSvc")
+	defer trace.CatchPanic("crowdsec/StartRunSvc")
 
 	// Set a default logger with level=fatal on stderr,
 	// in addition to the one we configure afterwards
@@ -38,7 +39,7 @@ func StartRunSvc() error {
 		return err
 	}
 
-	log.Infof("Crowdsec %s", cwversion.VersionStr())
+	log.Infof("Crowdsec %s", version.String())
 
 	apiReady := make(chan bool, 1)
 	agentReady := make(chan bool, 1)
