@@ -5,8 +5,9 @@ import (
 	"fmt"
 	"io"
 
+	"github.com/crowdsecurity/go-cs-lib/pkg/yamlpatch"
+
 	"github.com/crowdsecurity/crowdsec/pkg/models"
-	"github.com/crowdsecurity/crowdsec/pkg/yamlpatch"
 	"github.com/pkg/errors"
 	"gopkg.in/yaml.v2"
 )
